# Py Advys

Biblioteca com ferramentas para auxiliar no desenvolvimento de aplicações!

### instalação
```
pip install --upgrade PyAdvys
```
### Inicializa configurações
```
pyadvys-config-ini
```
## Pacotes

* advys_configuracoes
* advys_estrutura
* advys_servicos
* advys_utilitarios
* advys_validadores